@@ -16,4 +16,4 @@ from .dict_utils import dict_nested_read
 from .extract_words import is_nltk_word, extract_words
 from .regexp import alphabet_regexp, word_regexp, upper_regexp
 from .nlp import is_regular_word
-from .lazy_data import LazyData
+from .lazy_data import ld
